@@ -415,8 +415,10 @@ fi
 sudo apt-get update | while read line; do echo -n "."; done
 echo
 
-# Install the packages!
-sudo apt-get install %s
+# Install the packages using the option "--no-remove" to avoid
+# unexpected dependencies cycle that end up removing packages that are
+# essential for the OS to run
+sudo apt-get install --no-remove %s
 echo $? >%s
 echo -n "Press return to continue: "
 read line
@@ -556,7 +558,9 @@ def main():
 
         dependencies.append(row)
 
+    ensure_installed_packages = set()
     if get_arch() == 'amd64':
+        # If we are using the arch amd64 we also want these packages
         for synthetic in (
                 'libc6',
                 'libgl1-mesa-dri',
@@ -566,6 +570,7 @@ def main():
             if package is not None:
                 packages[package.name] = package
                 dependencies.append([package])
+                ensure_installed_packages.add(package)
 
     # Try to install these packages, even if they are not
     # listed in the steamdeps.txt file. If they are not available we
@@ -635,7 +640,7 @@ def main():
         packages[name].set_installed(match.group(2))
 
     # See which ones need to be installed
-    needed = []
+    needed = set()
     for row in dependencies:
         if len(row) == 0:
             continue
@@ -646,11 +651,11 @@ def main():
                 satisfied = True
                 break
         if not satisfied:
-            needed.append(row[0])
+            needed.add(row[0])
 
     # If we have anything to install, do it!
     if len(needed) > 0:
-        for package in needed:
+        for package in sorted(needed, key=lambda x: x.name):
             if package.installed:
                 print("Package %s is installed with version '%s' but doesn't "
                       "match requirements: %s" % (
@@ -663,7 +668,12 @@ def main():
         if args.dry_run:
             return 1
         else:
-            return update_packages(needed)
+            # If we are going to install additional packages, we also add the
+            # ones listed in "ensure_installed_packages". If they were already
+            # installed, this forces apt to keep them into consideration when
+            # it evaluates the new packages dependencies.
+            needed.update(ensure_installed_packages)
+            return update_packages(sorted(needed, key=lambda x: x.name))
     else:
         return 0
 
